@@ -2,8 +2,7 @@
 import sys
 
 from gooey import Gooey, GooeyParser
-from comFunction import get_list
-from mainflow.main_process import main_process
+from main_process import main_process,get_list
 
 
 @Gooey(
